@@ -487,9 +487,9 @@ class BucketDeployment(
                 id: builtins.str,
                 *,
                 destination_bucket: aws_cdk.aws_s3.IBucket,
-                sources: typing.Sequence["ISource"],
+                sources: typing.Sequence[ISource],
                 access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
-                cache_control: typing.Optional[typing.Sequence["CacheControl"]] = None,
+                cache_control: typing.Optional[typing.Sequence[CacheControl]] = None,
                 content_disposition: typing.Optional[builtins.str] = None,
                 content_encoding: typing.Optional[builtins.str] = None,
                 content_language: typing.Optional[builtins.str] = None,
@@ -503,14 +503,14 @@ class BucketDeployment(
                 include: typing.Optional[typing.Sequence[builtins.str]] = None,
                 log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
                 memory_limit: typing.Optional[jsii.Number] = None,
-                metadata: typing.Optional[typing.Union["UserDefinedObjectMetadata", typing.Dict[str, typing.Any]]] = None,
+                metadata: typing.Optional[typing.Union[UserDefinedObjectMetadata, typing.Dict[str, typing.Any]]] = None,
                 prune: typing.Optional[builtins.bool] = None,
                 retain_on_delete: typing.Optional[builtins.bool] = None,
                 role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-                server_side_encryption: typing.Optional["ServerSideEncryption"] = None,
+                server_side_encryption: typing.Optional[ServerSideEncryption] = None,
                 server_side_encryption_aws_kms_key_id: typing.Optional[builtins.str] = None,
                 server_side_encryption_customer_algorithm: typing.Optional[builtins.str] = None,
-                storage_class: typing.Optional["StorageClass"] = None,
+                storage_class: typing.Optional[StorageClass] = None,
                 use_efs: typing.Optional[builtins.bool] = None,
                 vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
                 vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
@@ -694,9 +694,9 @@ class BucketDeploymentProps:
             def stub(
                 *,
                 destination_bucket: aws_cdk.aws_s3.IBucket,
-                sources: typing.Sequence["ISource"],
+                sources: typing.Sequence[ISource],
                 access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
-                cache_control: typing.Optional[typing.Sequence["CacheControl"]] = None,
+                cache_control: typing.Optional[typing.Sequence[CacheControl]] = None,
                 content_disposition: typing.Optional[builtins.str] = None,
                 content_encoding: typing.Optional[builtins.str] = None,
                 content_language: typing.Optional[builtins.str] = None,
@@ -710,14 +710,14 @@ class BucketDeploymentProps:
                 include: typing.Optional[typing.Sequence[builtins.str]] = None,
                 log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
                 memory_limit: typing.Optional[jsii.Number] = None,
-                metadata: typing.Optional[typing.Union["UserDefinedObjectMetadata", typing.Dict[str, typing.Any]]] = None,
+                metadata: typing.Optional[typing.Union[UserDefinedObjectMetadata, typing.Dict[str, typing.Any]]] = None,
                 prune: typing.Optional[builtins.bool] = None,
                 retain_on_delete: typing.Optional[builtins.bool] = None,
                 role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-                server_side_encryption: typing.Optional["ServerSideEncryption"] = None,
+                server_side_encryption: typing.Optional[ServerSideEncryption] = None,
                 server_side_encryption_aws_kms_key_id: typing.Optional[builtins.str] = None,
                 server_side_encryption_customer_algorithm: typing.Optional[builtins.str] = None,
-                storage_class: typing.Optional["StorageClass"] = None,
+                storage_class: typing.Optional[StorageClass] = None,
                 use_efs: typing.Optional[builtins.bool] = None,
                 vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
                 vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
